@@ -1,5 +1,5 @@
 #! /bin/sh
-scripts/extract_strings_ki18n.py `find templates -name \*.html` >> html.cpp
+$EXTRACT_GRANTLEE_TEMPLATE_STRINGS `find src/templates -name \*.html` >> html.cpp
 $EXTRACTRC *.kcfg *.ui >> rc.cpp
 $XGETTEXT rc.cpp html.cpp src/*.cpp src/*.h -o $podir/libkcalutils5.pot
 rm -f rc.cpp html.cpp
